@@ -19,28 +19,87 @@ except ImportError:
 from optimade.adapters import Structure
 
 from optimade_client import exceptions
+from optimade_client.logger import LOGGER
 from optimade_client.subwidgets import (
     StructureSummary,
     StructureSites,
 )
+from optimade_client.utils import ButtonStyle
 from optimade_client.warnings import OptimadeClientWarning
 
 
-class OptimadeSummaryWidget(ipw.VBox):
+class OptimadeSummaryWidget(ipw.Box):
     """Overview of OPTIMADE entity (focusing on structure)
-    Combined view of structure viewer on the left and tabs on the right for detailed information
+    Combined view of structure viewer and tabs for detailed information.
+
+    Set `direction` to "horizontal" or "vertical" to show the two widgets either
+    horizontally or vertically, respectively.
     """
 
     entity = traitlets.Instance(Structure, allow_none=True)
 
-    def __init__(self, **kwargs):
-        self.viewer = StructureViewer(**kwargs)
-        self.summary = SummaryTabs(**kwargs)
+    def __init__(
+        self,
+        direction: str = None,
+        button_style: Union[ButtonStyle, str] = None,
+        **kwargs,
+    ):
+        if direction and direction == "horizontal":
+            direction = "row"
+            layout_viewer = {
+                "width": "50%",
+                "height": "auto",
+                "margin": "0px 0px 0px 0px",
+                "padding": "0px 0px 10px 0px",
+            }
+            layout_tabs = {
+                "width": "50%",
+                "height": "345px",
+            }
+        else:
+            direction = "column"
+            layout_viewer = {
+                "width": "auto",
+                "height": "auto",
+                "margin": "0px 0px 0px 0px",
+                "padding": "0px 0px 10px 0px",
+            }
+            layout_tabs = {
+                "width": "auto",
+                "height": "345px",
+            }
+
+        if button_style:
+            if isinstance(button_style, str):
+                button_style = ButtonStyle[button_style.upper()]
+            elif isinstance(button_style, ButtonStyle):
+                pass
+            else:
+                raise TypeError(
+                    "button_style should be either a string or a ButtonStyle Enum. "
+                    f"You passed type {type(button_style)!r}."
+                )
+        else:
+            button_style = ButtonStyle.DEFAULT
+
+        kwargs.pop("layout", None)
+
+        self.viewer = StructureViewer(
+            layout=layout_viewer, button_style=button_style, **kwargs
+        )
+        self.summary = SummaryTabs(layout=layout_tabs, **kwargs)
 
         self.children = (self.viewer, self.summary)
+
         super().__init__(
             children=self.children,
-            layout=ipw.Layout(width="auto", height="auto"),
+            layout={
+                "display": "flex",
+                "flex_flow": direction,
+                "align_items": "stretch",
+                "width": "100%",
+                "height": "auto",
+            },
             **kwargs,
         )
 
@@ -115,7 +174,7 @@ class DownloadChooser(ipw.HBox):
         # ),
     ]
     _download_button_format = """
-<input type="button" class="jupyter-widgets jupyter-button widget-button" value="Download" title="Download structure" style="width:auto;" {disabled}
+<input type="button" class="p-Widget jupyter-widgets jupyter-button widget-button mod-{button_style}" value="Download" title="Download structure" style="width:auto;" {disabled}
 onclick="var link = document.createElement('a');
 link.href = 'data:charset={encoding};base64,{data}';
 link.download = '{filename}';
@@ -124,11 +183,30 @@ link.click();
 document.body.removeChild(link);" />
 """
 
-    def __init__(self, **kwargs):
-        self.dropdown = ipw.Dropdown(options=("Select a format", {}), width="auto")
+    def __init__(self, button_style: Union[ButtonStyle, str] = None, **kwargs):
+        if button_style:
+            if isinstance(button_style, str):
+                self._button_style = ButtonStyle[button_style.upper()]
+            elif isinstance(button_style, ButtonStyle):
+                self._button_style = button_style
+            else:
+                raise TypeError(
+                    "button_style should be either a string or a ButtonStyle Enum. "
+                    f"You passed type {type(button_style)!r}."
+                )
+        else:
+            self._button_style = ButtonStyle.DEFAULT
+
+        self.dropdown = ipw.Dropdown(
+            options=("Select a format", {}), layout={"width": "auto"}
+        )
         self.download_button = ipw.HTML(
             self._download_button_format.format(
-                disabled="disabled", encoding="", data="", filename=""
+                button_style=self._button_style.value,
+                disabled="disabled",
+                encoding="",
+                data="",
+                filename="",
             )
         )
 
@@ -141,6 +219,7 @@ document.body.removeChild(link);" />
     @traitlets.observe("structure")
     def _on_change_structure(self, change: dict):
         """Update widget when a new structure is chosen"""
+        LOGGER.debug("Got new structure for DownloadChooser: %s", change["new"])
         if change["new"] is None:
             self.reset()
         else:
@@ -151,6 +230,10 @@ document.body.removeChild(link);" />
         """Update options according to chosen structure"""
         # Disordered structures not usable with ASE
         if "disorder" in self.structure.structure_features:
+            LOGGER.debug(
+                "'disorder' found in the structure's structure_features (%s)",
+                self.structure.structure_features,
+            )
             options = sorted(
                 [
                     option
@@ -162,6 +245,7 @@ document.body.removeChild(link);" />
         else:
             options = sorted(self._formats)
             options.insert(0, ("Select a format", {}))
+        LOGGER.debug("Will set the dropdown options to: %s", options)
         self.dropdown.options = options
 
     def _update_download_button(self, change: dict):
@@ -173,9 +257,16 @@ document.body.removeChild(link);" />
         `optimade-python-tools` and/or any related exceptions.
         """
         desired_format = change["new"]
+        LOGGER.debug(
+            "Updating the download button with desired format: %s", desired_format
+        )
         if not desired_format or desired_format is None:
             self.download_button.value = self._download_button_format.format(
-                disabled="disabled", encoding="", data="", filename=""
+                button_style=self._button_style.value,
+                disabled="disabled",
+                encoding="",
+                data="",
+                filename="",
             )
             return
 
@@ -199,17 +290,29 @@ document.body.removeChild(link);" />
                     )
                 else:
                     self.download_button.value = self._download_button_format.format(
-                        disabled="disabled", encoding="", data="", filename=""
+                        button_style=self._button_style.value,
+                        disabled="disabled",
+                        encoding="",
+                        data="",
+                        filename="",
                     )
                     warnings.warn(OptimadeClientWarning(warn))
             except Warning as warn:
                 self.download_button.value = self._download_button_format.format(
-                    disabled="disabled", encoding="", data="", filename=""
+                    button_style=self._button_style.value,
+                    disabled="disabled",
+                    encoding="",
+                    data="",
+                    filename="",
                 )
                 warnings.warn(OptimadeClientWarning(warn))
             except Exception as exc:
                 self.download_button.value = self._download_button_format.format(
-                    disabled="disabled", encoding="", data="", filename=""
+                    button_style=self._button_style.value,
+                    disabled="disabled",
+                    encoding="",
+                    data="",
+                    filename="",
                 )
                 if isinstance(exc, exceptions.OptimadeClientError):
                     raise exc
@@ -237,7 +340,11 @@ document.body.removeChild(link);" />
         data = base64.b64encode(output).decode()
 
         self.download_button.value = self._download_button_format.format(
-            disabled="", encoding=encoding, data=data, filename=filename
+            button_style=self._button_style.value,
+            disabled="",
+            encoding=encoding,
+            data=data,
+            filename=filename,
         )
 
     @staticmethod
@@ -280,6 +387,7 @@ document.body.removeChild(link);" />
 
     def unfreeze(self):
         """Activate widget (in its current state)"""
+        LOGGER.debug("Will unfreeze %s", self.__class__.__name__)
         for widget in self.children:
             widget.disabled = False
 
@@ -311,11 +419,12 @@ class StructureViewer(ipw.VBox):
             },
         )
 
-        self.download = DownloadChooser(**kwargs)
+        button_style = kwargs.pop("button_style", None)
+        self.download = DownloadChooser(button_style=button_style, **kwargs)
 
-        super().__init__(
-            children=(self.viewer_box, self.download),
-            layout={
+        layout = kwargs.pop(
+            "layout",
+            {
                 "width": "auto",
                 "height": "auto",
                 "margin": "0px 0px 0px 0px",
@@ -323,6 +432,12 @@ class StructureViewer(ipw.VBox):
             },
         )
 
+        super().__init__(
+            children=(self.viewer_box, self.download),
+            layout=layout,
+            **kwargs,
+        )
+
         self.observe(self._on_change_structure, names="structure")
 
         traitlets.dlink((self, "structure"), (self.download, "structure"))
@@ -364,9 +479,17 @@ class SummaryTabs(ipw.Tab):
             ("Sites", StructureSites()),
         )
 
+        layout = kwargs.pop(
+            "layout",
+            {
+                "width": "auto",
+                "height": "345px",
+            },
+        )
+
         super().__init__(
             children=tuple(_[1] for _ in self.sections),
-            layout=ipw.Layout(width="auto", height="345px"),
+            layout=layout,
             **kwargs,
         )
         for index, title in enumerate([_[0] for _ in self.sections]):
